/* Please do not attemp to run this program without reading the accompanying documentation. */

version 8.0
set more off
prog drop _all
capture log close
clear

/*
File: extract_91.do
Date: August 11, 2003
Desc: This program extracts the 1991 data.
Note: See copyright notice at the end of this program.
*/

/* Acknowledgements

I am grateful to Jean Roth and others at the NBER for their efforts to make 
the data widely available. Many thanks also to Helen Connolly, Danielle Gao, 
Noelle (Bethney) Gundersen, John Schmitt, Jeffrey Sisson, Jeffrey Wenger and 
the SIPP Outreach Staff at the U.S. Census Bureau for helpful discussions 
about the SIPP data. Bradley Hardy provided valuable research assistance on 
this project.

The construction of this SIPP extract has been funded by a generous grant from 
the Rockefeller Foundation.

The *.do and *.dct files associated with this extract program that begin with the 
prefix "sip" were initially created by Jean Roth at the National Bureau of 
Economic Research, although they have been edited for use in this program. 
Complete details and all underlying data are available from the NBER 
(www.nber.org). Please report errors in those program to jroth@nber.org. 
Copyright 2003 shared by Jean Roth and the National Bureau of Economic Research.

The underlying Survey of Income and Program Participation data referenced here 
are in the public domain. The programs are distributed under the GNU GPL. 
See end of this file and http://www.gnu.org/licenses/ for details.

*/

/* USER NOTES

This program will read the 1992 SIPP panel into Stata format and label 
the variables and their values. The underlying data must be downloaded from 
the NBER (http://www.nber.org/data/sipp.html), or from the U.S. Census. 
The raw data will come in *.dat format. Downloading directions can 
be found at the CEPR websited (http:///www.cepr.net/data/sipp_extract.html). 

CEPR's extract programs are meant to substitute for the NBER *.dct and 
*.do files so these do not need to be downloaded from the NBER. In particular, 
the CEPR programs have changed the format of the variables necessary 
to generate the unique id from numeric into string in order to 
concatenate them correctly.

Prior to running this program, the user should create two directories and 
suggested names are below. If you choose not to create directories with the 
following names, you must change the directories referred to below as well as 
make changes in every *.do and *.dct file associated with this extract program 
to reflect your preferred directory structure. This process will be much 
less painful if you use the directory names suggested below.

Save all *.do and *.dct files (from CEPR) in the following directory:
c:\_files\programs\sipp\extract\sipp92\

Save all unzipped *.dat files (from the NBER or the U.S. Census) in the 
following directory:
c:\_files\data\sipp\sipp92\

This program was written for Intercooled Stata Version 8.0. It is 
recommended that you have 1GB of ram memory. 

Please direct all questions to <datahelp@cepr.net>.
*/


	/* Windows vs. GNU/Linux */
global gnulin=1 /* set equal to zero for Windows */
	
	/* GNU/Linux */
if $gnulin==1 {
/*If you run GNU/Linux, be sure to change $rootdir to match your root directory*/
global rootdir /ceprdata/sipp
global programs $rootdir/programs/extract/sipp91
global log $rootdir/programs/extract/sipp91
global dictdir $rootdir/programs/extract/sipp91
global rawdata $rootdir/rawdata
global output $rootdir/rawdata
}

	/* Windows */
if $gnulin==0 {
/*If you run Windows, be sure to change $rootdir to match your root directory*/
global rootdir "f:\_files\ceprdata\sipp"
global programs "$rootdir\programs\extract\sipp91"
global log "$rootdir\programs\extract\sipp91"
global dictdir "$rootdir\programs\extract\sipp91"
global rawdata "$rootdir\rawdata"
global output "$rootdir\rawdata"
}

/*For job ID variables*/
/*

log using "f:\_files\programs\sipp\extract\sipp91\sip91jid2`i'.log", replace

	* Macro for location of dictionary files
	global dict = "f:\_files\programs\sipp\extract\sipp91\sip91jid.dct"
	* Macro for location of raw (unzipped) SIPP data
	global data = "f:\_files\data\sipp\sipp91\sipp91jid.dat"
		
	do "f:\_files\programs\sipp\extract\sipp91\sip91jid`i'.do"
		
	sort suid entry pnum
	egen id = concat(suid entry pnum)
	sort id
	save "f:\_files\data\sipp\sipp91\sipp91jid.dta", replace
	log close
	clear

*/
*capture program drop loopfp
*program define loopfp
* Longitudinal
/* The full longitudinal panel has more than 2,047 variables, which is the 
maximum allowed in Intercooled Stata. To get around this, I've divided
the longitudinal panel up into three smaller datasets.
*/

local i = 1
while `i'<4 {
	cd $log
	log using sip91fp`i'.log, replace
	
	/*Macros for dictionary files and raw SIPP data files*/
	
	if $gnulin==1 {
	global dict_name "$dictdir/sip91fp`i'.dct"
	global data_name "$rawdata/sipp91fp.dat"
	}
	if $gnulin==0 {
	global dict_name "$dictdir\sip91fp`i'.dct"
	global data_name "$rawdata\sipp91fp.dat"
	}
	
	cd $programs		
	do sip91fp`i'.do
	
	/* NOTE: pp_entry and pp_pnum assume 10 waves in the longitudinal file. However
	there are only 9 and so we delete the extra digit for these two vars. This 
	results in the loss of 0.003% of the observations in the longtidunial file.
	*/
	sort pp_id pp_entry pp_pnum
	egen id = concat(pp_id pp_entry pp_pnum)
	sort id
	
	cd $output
	save sipp91l`i'.dta, replace
	log close
	clear
	local i=`i'+1
	}
end	
*/

/*
capture program drop loop1
program define loop1
*/
* Core and Topical Module Files

/*
while "`1'"~="" {
	local i=2
	while `i'<9 {
		cd $log
		log using sip91`1'`i'.log, replace 
		
		if $gnulin==1 {
		global dict_name "$dictdir/sip91`1'`i'.dct"
		global data_name "$rawdata/sipp91`1'`i'.dat"
		}
		if $gnulin==0 {
		global dict_name "$dictdir\sip91`1'`i'.dct"
		global data_name "$rawdata\sipp91`1'`i'.dat"
		}
		
		do sip91`1'`i'.do"
		
		* If topical module, change <id> to <suid> and <rotation> to <rot>
		if "`1'"=="t" {
		rename id suid
		rename rotation rot
		}
		sort suid entry pnum
		egen id = concat(suid entry pnum)
		
		* If core data, give <reference month> a uniform name
		if "`1'"=="w" {
		rename refmth srefmon
		}
		
		sort id
		
		cd $output
		save sipp91`1'`i'.dta", replace
		log close
		clear
		local i=`i'+1
	}
	mac shift	
}
end


capture program drop loopr
program define loopr
* Research files for waves 5 and 8
local i=5
while `i'<10 {
	cd $log
	log using sip91r`i'.log, replace 

	if $gnulin==1 {
	global dict_name "$dictdir/sip91r`i'.dct"
	global data_name "$rawdata/sipp91r`i'.dat"
	}
	if $gnulin==0 {
	global dict_name "$dictdir\sip91r`i'.dct"
	global data_name "$rawdata\sipp91r`i'.dat"
	}	
	
	cd $programs
	do sip91r`i'.do

	rename id suid
	rename rotation rot
	sort suid entry pnum
	egen id = concat(suid entry pnum)

	sort id rot
	
	cd $output
	save sipp91r`i'.dta, replace
	log close
	clear
	local i=`i'+3
	}
end
*/
*loopfp
*loop1 t
*loopr


